@@ -80,6 +80,9 @@ dpkg_status (lua_State * L)
 	  lua_error (L);
 	}
 
+#ifdef HAVE_PKG_STATUS_NAME
+      lua_pushstring (L, pkg_status_name (p));
+#else
       switch (p->status)
 	{
 	case stat_notinstalled:
@@ -109,6 +112,7 @@ dpkg_status (lua_State * L)
 	default:
 	  lua_pushinteger (L, p->status);
 	}
+#endif
       j++;
     }
   return j;
