@@ -1,5 +1,5 @@
 -- deets: resource.lua
--- Copyright (C) 2009, 2011  Clint Adams
+-- Copyright (C) 2009-2012  Clint Adams
 
 -- This program is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -12,15 +12,15 @@
 -- GNU General Public License for more details.
 
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
 require("utils-table")
 
 defaultprovider = {
-  pkg="apt",
-  file="file"
+   pkg="apt"
+ , file="file"
+ , aug="augeas"
 }
 
 resource = {}
@@ -58,6 +58,8 @@ function audit_resource(res)
     return debian.iscompliant(resource[res].name, resource[res])
   elseif (resource[res].provider == "file") then
     return file.iscompliant(resource[res].name, resource[res])
+  elseif (resource[res].provider == "augeas") then
+    return aug.iscompliant(resource[res].name, resource[res])
   else
     return "UnclueII:"..resource[res]
   end
@@ -68,6 +70,8 @@ function rectify_resource(res)
     return debian.rectify(resource[res].name, resource[res])
   elseif (resource[res].provider == "file") then
     return file.rectify(resource[res].name, resource[res])
+  elseif (resource[res].provider == "augeas") then
+    return aug.rectify(resource[res].name, resource[res])
   else
     return "Unclue:"..resource
   end
